import type { RequestHandler } from '@apollo/client';
import { NetworkData, ProgressCallback } from '../utils/XhrNetworkInterceptor';
import { NetworkListenerType } from '../native/NativeNetworkLogger';
export type { NetworkData };
export type NetworkDataObfuscationHandler = (data: NetworkData) => Promise<NetworkData>;
/**
 * Sets whether network logs should be sent with bug reports.
 * It is enabled by default.
 * @param isEnabled
 */
export declare const setEnabled: (isEnabled: boolean) => void;
/**
 * @internal
 * Sets whether enabling or disabling native network interception.
 * It is disabled by default.
 * @param isEnabled
 */
export declare const setNativeInterceptionEnabled: (isEnabled: boolean) => void;
export declare const getNetworkDataObfuscationHandler: () => NetworkDataObfuscationHandler | null | undefined;
export declare const getRequestFilterExpression: () => string;
export declare const hasRequestFilterExpression: () => boolean;
/**
 * Obfuscates any response data.
 * @param handler
 */
export declare const setNetworkDataObfuscationHandler: (handler?: NetworkDataObfuscationHandler | null | undefined) => void;
/**
 * Omit requests from being logged based on either their request or response details
 * @param expression
 */
export declare const setRequestFilterExpression: (expression: string) => void;
/**
 * Returns progress in terms of totalBytesSent and totalBytesExpectedToSend a network request.
 * @param handler
 */
export declare const setProgressHandlerForRequest: (handler: ProgressCallback) => void;
export declare const apolloLinkRequestHandler: RequestHandler;
/**
 * Sets whether network body logs will be captured or not.
 * @param isEnabled
 */
export declare const setNetworkLogBodyEnabled: (isEnabled: boolean) => void;
/**
 * @internal
 * Exported for internal/testing purposes only.
 */
export declare const resetNetworkListener: () => void;
/**
 * @internal
 * Exported for internal/testing purposes only.
 */
export declare const registerNetworkLogsListener: (type: NetworkListenerType, handler?: ((networkSnapshot: NetworkData) => void) | undefined) => void;
